@@ -85,13 +85,14 @@ class Capture(object):
         negate = f[protocol][field]['negate']
         negate_str = ' != ' if negate else ' == '
 
-        bpf = '{0}{1}{2}{3}{4}{5}'.format(
+        bpf = '{0}{1}{2}{3}{4}{5}{6}'.format(
             filter_info[protocol]['name'],
             filter_info[protocol][field]['offset'],
             ' & ' + hex(filter_info[protocol][field]['mask']),
             mask_str,
             negate_str,
-            value_str
+            value_str,
+            mask_str
         )
         return bpf
 
