@@ -9,7 +9,7 @@ class Link(object):
 
     def set_link(self, payload, port_ids):
         ports = list(range(len(port_ids)))
-        if payload.port_names is not None:
+        if payload.port_names is not None  and len(payload.port_names) > 0:
             ports = []
             for p_name in payload.port_names:
                 ports.append(port_ids.index(p_name))
